@@ -1,7 +1,7 @@
 class UC:
     domain = "https://userscloud.com"
 
-    def __init__(self, debug: bool = False):
+    def __init__(self, *, debug: bool = False):
         self.debug = debug
 
 
